#!/usr/bin/bash

set -e

CRATE="opml"
NAME="rust-${CRATE}"

VERSION=$(rpmspec -q $NAME.spec --srpm --qf "%{version}")
URL="https://crates.io/api/v1/crates/${CRATE}/${VERSION}/download"

ROOTDIR="${CRATE}-${VERSION}"

# download and extract published crate from crates.io
wget $URL -O ${ROOTDIR}.crate
tar -xzf ${ROOTDIR}.crate
rm ${ROOTDIR}.crate

pushd ${ROOTDIR}
# remove files with questionable licenses and tests that need them
rm -r tests
# clean up cargo files
rm .cargo_vcs_info.json Cargo.lock
mv Cargo.toml.orig Cargo.toml
# init git repository
git init && git add . && git commit -m "import"
# repackage crate
cargo package
# move clean crate
mv target/package/${ROOTDIR}.crate ../${ROOTDIR}-clean.crate
popd

# remove temporary directory
rm -rf ${ROOTDIR}

